using System;
using System.Collections.Generic;
using System.Text;

namespace Database
{
    public class TransducerDatabase
    {
        /// <summary>
        /// List of transducer
        /// </summary>
        private List<TransducerDatabaseItem> items;

        /// <summary>
        /// MSX-E system
        /// </summary>
        private MSXExxxx mx;

        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="mx"></param>
        public TransducerDatabase(MSXExxxx mx)
        {
            this.items = new List<TransducerDatabaseItem>();
            this.mx = mx;
        }

        /// <summary>
        /// Add a transducer inside the database
        /// </summary>
        /// <param name="item"></param>
        /// <returns>
        /// 0: success
        /// -1: transducer still in the list
        /// </returns>
        public int AddTransducer(TransducerDatabaseItem item, ref string error)
        {
            // Check if the system is inside the list
            foreach (TransducerDatabaseItem i in this.items)
            {
                if (i.index == item.index)
                {
                    error = "The transducer is still in the list.";
                    return -1;
                }
            }

            // Add it to the MSX-E system
            if (this.mx.TransducerDatabaseAdd(item, ref error) != 0)
                return -2;

            // Ok add it to the internal database
            this.items.Add(item);
            
            return 0;
        }

        /// <summary>
        /// Load from the MSX-E system
        /// </summary>
        /// <param name="error"></param>
        /// <returns></returns>
        public int LoadFromSystem(ref string error)
        {
            // Clear the items
            items.Clear();

            // Read and return
            return this.mx.TransducerDatabaseGetList(ref this.items, ref error);
        }

        /// <summary>
        /// Access on the items
        /// </summary>
        public List<TransducerDatabaseItem> Items
        {
            get
            {
                return this.items;
            }
        }

        /// <summary>
        /// Remove an item from the database
        /// </summary>
        /// <param name="index"></param>
        /// <param name="error"></param>
        /// <returns></returns>
        public int RemoveItemByIndex(int index, ref string error)
        {
            if (index >= this.items.Count)
            {
                error = "RemoveItemByIndex: Index is wrong.";
                return -1;
            }

            if (this.mx.TransducerDatabaseDelete(this.items[index].index, ref error) != 0)
                return -2;

            this.items.RemoveAt(index);
            return 0;
        }
    }
}
